package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"````````!``````````&BQ````
M`````````$``.``)`$``'``;``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````'B=````````>)T`````````
M`"````````$````&````D*L```````"0JR```````)"K(```````D`0`````
M```8%0``````````(````````@````8```"XJP```````+BK(```````N*L@
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````B)8```````"(E@```````(B6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)"K````````D*L@``````"0JR``
M`````'`$````````<`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50"D][G46[DXT"R,&^)D.<V2T3CUD!$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````YP$``!(`````````````````````````70(``!(`
M````````````````````````.P(``!(`````````````````````````$0``
M`"``````````````````````````9`(``!(`````````````````````````
M\`(``!(`````````````````````````M````!(`````````````````````
M````>0(``!(`````````````````````````@P$``!(`````````````````
M````````V`(``!(`````````````````````````T`(``!(`````````````
M````````````A````!(`````````````````````````L0,``!(`````````
M````````````````#`$``!(`````````````````````````G`(``!(`````
M````````````````````C@(``!(`````````````````````````3`(``!(`
M````````````````````````Z0(``!(`````````````````````````!@,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````%`(``!(`````````````````
M````````0P(``!(`````````````````````````)`(``!(`````````````
M````````````G@$``!(`````````````````````````<@(``!(`````````
M````````````````X@$``!(`````````````````````````2@,``!(`````
M````````````````````0P,``!(`````````````````````````0P$``!(`
M````````````````````````^0(``!(`````````````````````````+0``
M`"``````````````````````````L`(``!(`````````````````````````
M9````!(```````````````````````````(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````MP(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````:@(``!(`````````````````````````VP$`
M`!(`````````````````````````-`,``!(`````````````````````````
M#0,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````/`,``!(`````````````````
M````````AP(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````Q0(``!(`````````
M````````````````-@(``!(`````````````````````````^`$``!(`````
M````````````````````H@(``!(`````````````````````````/````"``
M````````````````````````@`(``!(`````````````````````````%P,`
M`"(`````````````````````````E0(``!(`````````````````````````
M)@,``!(`````````````````````````N@,``!(`#@`P5@```````'``````
M````B`,``!(`#P`D5P``````````````````WP,``!(`#@`@1@```````!0,
M````````5P,``!(`#@`P'@```````"T"````````C@,``!(`#@"`/P``````
M``4`````````300``!(`#@"0/P```````/H!````````1P0``!(`"P!`&@``
M````````````````>@0``!(`#@!`4@```````.T#````````;0,``!``&0`@
ML"``````````````````Q@,``!(`#@"000```````"H`````````^0,``!$`
M$``P5P````````0`````````O`$``!$`%0"@JR```````!,`````````>0,`
M`!``&0"HP"``````````````````100``!(`#@`P/@```````#``````````
M6@0``!(`#@!`10```````-P`````````;`0``!(`#@"01````````'0`````
M````[`,``!``&```L"``````````````````TP,``!(`#@#`00```````.P`
M````````7`,``!$`&0!(L"````````@`````````9@,``!``&``@L"``````
M````````````70,``"$`&0!(L"````````@`````````+@0``!$`&``8L"``
M``````@`````````X@(``!$`&0!@L"````````@`````````?@,``!(`#@`@
M5P````````(`````````'@0``!(`#@"P5@```````&4`````````\@,``!(`
M#@!@(````````"L`````````[@,``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````7@,``"$`&0!(L"````````@`````````
MGP,``!(`#@`010```````"0`````````"`0``!(`#@"P/@```````,$`````
M````XP```!$`&0!`L"````````$`````````.`0``!(`#@"P0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?
M97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ
M90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D
M:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S
M960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"
M3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXT``````(``P`"``(````"``(````"`````@`"````
M`@````(``@`$``(``@````````````,``@`%`````@`#``(``@````8````'
M`````P`"``````````````````8```````(``P`"``(```````(``@``````
M`@`"``,`!@````(``@`"``8``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$``@`!``(``0`"``$``0`!``$````"``$``0````$```````$`
M`0#+`0``$````"````!U&FD)```#`)`$`````````0`%`!H"```0````````
M`)21E@8```<`G`0``!````!T&6D)```&`*<$```0````<AEI"0``!0"S!```
M$````!1I:0T```0`OP0``!````!U&FD)```"`)`$````````D*L@```````(
M`````````&`A````````F*L@```````(`````````"`A````````"+`@````
M```(``````````BP(```````&+`@```````(`````````%!:````````N*\@
M```````&````!0``````````````P*\@```````&````"@``````````````
MR*\@```````&````'P``````````````T*\@```````&````(P``````````
M````V*\@```````&````*P``````````````X*\@```````&````-@``````
M````````Z*\@```````&````/P``````````````\*\@```````&````00``
M````````````H*L@```````%````3P``````````````(+`@```````%````
M7P``````````````0+`@```````%````8P``````````````2+`@```````%
M````5@``````````````8+`@```````%````6@``````````````X*T@````
M```'`````0``````````````Z*T@```````'`````@``````````````\*T@
M```````'`````P``````````````^*T@```````'````!```````````````
M`*X@```````'````!@``````````````"*X@```````'````!P``````````
M````$*X@```````'````"```````````````&*X@```````'````"0``````
M````````(*X@```````'````"P``````````````**X@```````'````#```
M````````````,*X@```````'````#0``````````````.*X@```````'````
M#@``````````````0*X@```````'````#P``````````````2*X@```````'
M````$```````````````4*X@```````'````$0``````````````6*X@````
M```'````$@``````````````8*X@```````'````$P``````````````:*X@
M```````'````%```````````````<*X@```````'````%0``````````````
M>*X@```````'````%@``````````````@*X@```````'````%P``````````
M````B*X@```````'````&```````````````D*X@```````'````&0``````
M````````F*X@```````'````&@``````````````H*X@```````'````&P``
M````````````J*X@```````'````'```````````````L*X@```````'````
M'0``````````````N*X@```````'````'@``````````````P*X@```````'
M````(```````````````R*X@```````'````(0``````````````T*X@````
M```'````(@``````````````V*X@```````'````)```````````````X*X@
M```````'````)0``````````````Z*X@```````'````)@``````````````
M\*X@```````'````)P``````````````^*X@```````'````*```````````
M`````*\@```````'````*0``````````````"*\@```````'````*@``````
M````````$*\@```````'````+```````````````&*\@```````'````+0``
M````````````(*\@```````'````+@``````````````**\@```````'````
M+P``````````````,*\@```````'````,```````````````.*\@```````'
M````,0``````````````0*\@```````'````,@``````````````2*\@````
M```'````,P``````````````4*\@```````'````-```````````````6*\@
M```````'````-0``````````````8*\@```````'````-P``````````````
M:*\@```````'````.```````````````<*\@```````'````.0``````````
M````>*\@```````'````.@``````````````@*\@```````'````.P``````
M````````B*\@```````'````/```````````````D*\@```````'````/0``
M````````````F*\@```````'````/@``````````````H*\@```````'````
M0```````````````J*\@```````'````0@``````````````L*\@```````'
M````0P``````````````2(/L"$B+!865(`!(A<!T`O_02(/$",,`````````
M``#_-6J3(`#_)6R3(``/'T``_R5JDR``:`````#IX/____\E8I,@`&@!````
MZ=#_____)5J3(`!H`@```.G`_____R52DR``:`,```#IL/____\E2I,@`&@$
M````Z:#_____)4*3(`!H!0```.F0_____R4ZDR``:`8```#I@/____\E,I,@
M`&@'````Z7#_____)2J3(`!H"````.E@_____R4BDR``:`D```#I4/____\E
M&I,@`&@*````Z4#_____)1*3(`!H"P```.DP_____R4*DR``:`P```#I(/__
M__\E`I,@`&@-````Z1#_____)?J2(`!H#@```.D`_____R7RDB``:`\```#I
M\/[___\EZI(@`&@0````Z>#^____)>*2(`!H$0```.G0_O___R7:DB``:!(`
M``#IP/[___\ETI(@`&@3````Z;#^____)<J2(`!H%````.F@_O___R7"DB``
M:!4```#ID/[___\ENI(@`&@6````Z8#^____);*2(`!H%P```.EP_O___R6J
MDB``:!@```#I8/[___\EHI(@`&@9````Z5#^____)9J2(`!H&@```.E`_O__
M_R62DB``:!L```#I,/[___\EBI(@`&@<````Z2#^____)8*2(`!H'0```.D0
M_O___R5ZDB``:!X```#I`/[___\E<I(@`&@?````Z?#]____)6J2(`!H(```
M`.G@_?___R5BDB``:"$```#IT/W___\E6I(@`&@B````Z<#]____)5*2(`!H
M(P```.FP_?___R5*DB``:"0```#IH/W___\E0I(@`&@E````Z9#]____)3J2
M(`!H)@```.F`_?___R4RDB``:"<```#I</W___\E*I(@`&@H````Z6#]____
M)2*2(`!H*0```.E0_?___R4:DB``:"H```#I0/W___\E$I(@`&@K````Z3#]
M____)0J2(`!H+````.D@_?___R4"DB``:"T```#I$/W___\E^I$@`&@N````
MZ0#]____)?*1(`!H+P```.GP_/___R7JD2``:#````#IX/S___\EXI$@`&@Q
M````Z=#\____)=J1(`!H,@```.G`_/___R72D2``:#,```#IL/S___\ERI$@
M`&@T````Z:#\____)<*1(`!H-0```.F0_/___R6ZD2``:#8```#I@/S___\E
MLI$@`&@W````Z7#\____):J1(`!H.````.E@_/___R6BD2``:#D```#I4/S_
M__\EFI$@`&@Z````Z4#\____)<J1(`!FD```````````55-(@^PXB7PD'$B)
M="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`Z`C^__](
MBS5ID2``2(L]:I$@`$B)\N@B.```@#V[D2```'4OZ#3]__](A<!(B04*HB``
M#X2W`0``2(G'Z&S\__^+/7:1(`#HT?W__\:`T0@```"+/621(`#HO_W__X"(
MJ@0```*+/5*1(`#HK?W__X"(J@0```&+1"0<C7@%2+C_________'TAC_T@Y
MQP^'(@$``$C!YP-(C1T".@``Z/G\__](BWPD$$B)!76A(`#'!7.A(``$````
M2(L72(E8"$B-'=PY``!(B5@82(D02(L5WY`@`$B)4!"+5"0<@_H!1(U*!'XM
M1(U*!$B#QPB^!0```&8/'X0``````$R+!TACSH/&`4B#QPA!.?%,B43(^'7I
M2(L](J$@`$UCR4B--=@>``"#P@-%,<!*QT3(^`````!(B<'H8?W__X7`B<-T
M9$B+/?2@(`!(C6PD).C:^___2(T]%S@``#'`2(GNZ+D7``!(A<!T*DB+/<V@
M(`#H6/O__^CS_/__B=A(BUPD*&1(,QPE*````'5?2(/$.%M=PTB+/9N@(`!(
MA?]T+.@I-@``Z\-(BSV0H"``Z(O]__^)P^N,2(TU@(L@`$B-/5\W```QP.B"
M_/__2(T]5#<``$B)[NA#%P``2(7`2(G'2(D%3J`@`'2`Z[3H#?O__[\!````
MZ&/]__\/'P`Q[4F)T5Y(B>)(@^3P4%1,C06J-@``2(T-,S8``$B-/:S]____
M%3Z/(`#T#Q]$``!(C3V)CR``54B-!8&/(`!(.?A(B>5T&4B+!0J/(`!(A<!T
M#5W_X&8N#Q^$``````!=PP\?0`!F+@\?A```````2(T]28\@`$B--4*/(`!5
M2"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!>F.(`!(A<!T#%W_X&8/'X0`
M`````%W##Q]``&8N#Q^$``````"`/4&/(```=2](@SV_CB```%5(B>5T#$B+
M/<J.(`#HW?S__^A(____Q@49CR```5W##Q^``````//#9@\?1```54B)Y5WI
M9O___V8/'T0``$%7059,C4\X055!5$4QP%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>%FD$.+!`%+BS0!#\A(B?*)P$C!ZB!*B01!2(GP2,'N.$C!
MZ"@E`/\``$@)\$B)UDC!X@A(P>88@>(``/\`B?9("?!("=!*B41!"$F#P`A)
M@_A`=:Y(C;$``@``#Q^``````$B+06A(,T%`2(/!"$@S00A(,T'X2(T4`$C!
MZ!]("="#X/](B4%X2#GQ==5,BQ=(BU\02(MW($B+;QA,BT\(3(G03(G22,'J
M&TC!X`5("=`#!"2-E#"9>8):2(G82(MT)`A(,>A,(<A(,>A(C;0UF7F"6D2-
M+`),B<I,B<A(P>@"2,'B'D@)PDB)V$V)Z(G12<'H&T@QR$PAT$@QV$@!\$R)
M[DC!Y@5,"<9$C20&3(G63(G02,'F'DC!Z`)("?!(BW0D$$V)XT@QPDG!ZQM!
MB<!,(>I(C;0SF7F"6D@QRD@!\DR)YDC!Y@5,"=Y$C1P63(GN2(M4)!A)P>T"
M2,'F'DP)[D@Q\$B-E!&9>8):3(G93"'@08GV3#'`2,'I&T@!T$R)VDC!X@5(
M"<I,B>%)P>P"1(TL`DC!X1Y(BU0D($P)X4B)\$@QR$R)[D&)S$PAV$F-E!"9
M>8):2,'N&TPQ\$@!T$R)ZDC!X@5("?)$C00"3(G:2(M$)"A)P>L"2,'B'DP)
MVDR)QD@QT4F-A`:9>8):2,'N&TPAZ4&)TTPQX4@!P4R)P$C!X`5("?!$C30(
M3(GH2(M,)#!)P>T"2,'@'DP)Z$R)]D@QPDF-C`R9>8):08G%3"'"3#':2`'*
M3(GQ2,'A!4C![AM("?%,B<9)P>@"1(TD$4C!YAY(BU0D.$P)QD@Q\$R)X4&)
M\$PA\$F-E!.9>8):2,'I&TPQZ$@!T$R)XDC!X@5("<I,B?%)P>X"1(T<`DC!
MX1Y(BU0D0$P)\4B)\$@QR$R)WD&)SDPAX$F-E!69>8):2,'N&TPQP$@!T$R)
MVDC!X@5("?)$C2P"3(GB2(M$)$A)P>P"2,'B'DP)XDR)[D@QT4F-A`"9>8):
M2,'N&TPAV4&)U$PQ\4@!P4R)Z$C!X`5("?!$C00(3(G82(M,)%!)P>L"2,'@
M'DP)V$R)QD@QPDF-C`Z9>8):2,'N&TPAZD&)PTPQXD@!RDR)P4C!X05("?%,
MB>Y)P>T"1(TT$4C!YAY(BU0D6$P)[D@Q\$R)\4&)]4PAP$F-E!29>8):2,'I
M&TPQV$@!T$R)\DC!X@5("<I,B<%)P>@"1(TD`DC!X1Y(BU0D8$P)P4B)\$@Q
MR$R)YD&)R$F-E!.9>8):3"'P2,'N&TPQZ$@!T$R)XDC!X@5("?)$C1P"3(GR
M2(M$)&A(P>(>2<'N`DP)\DR)WD@QT4F-A`69>8):2,'N&TPAX4&)UDPQP4@!
MP4R)V$C!X`5("?!$C2P(3(G@2(M,)'!)P>P"2,'@'DP)X$R)[D@QPDF-C`B9
M>8):2,'N&TPAVD&)Q$PQ\D@!RDR)Z4C!X05("?%,B=Y)P>L"1(T$$4C!YAY(
MBU0D>$P)WD@Q\$R)P4&)\TPAZ$F-E!:9>8):2,'I&TPQX$@!T$R)PDC!X@5(
M"<I,B>E)P>T"1(TT`DC!X1Y(BY0D@````$P)Z4B)\$@QR$R)]D&)S4PAP$F-
ME!29>8):2,'N&TPQV$@!T$R)\DC!X@5("?)$C20"3(G"2(N$)(@```!)P>@"
M2,'B'DP)PDR)YD@QT4F-A`.9>8):2,'N&TPA\4&)T$PQZ4@!P4R)X$C!X`5(
M"?!(B[0DD````$2-'`A,B?!)P>X"2,'@'DP)\$F-M#69>8):38G=2#'"2<'M
M&XG!3"'B3#'"2`'R3(G>2,'F!4P)[HGV2`'R3(GF2<'L`DC!YAY!B=5,">9,
MBZ0DF````$@Q\$PAV$^-A""9>8):2#'(38GL2<'L&TP!P$V)Z$G!X`5-">!%
MB<!,`<!-B=A)P>L"2<'@'D&)Q$T)V$F)\XGV33'#2`.T)*@```!$,=I,BYPD
MH````$J-C!FAZ]EN38GC2<'K&T@!T4R)XDC!X@5,"=J)TD@!T4R)ZDG![0)(
MP>(>08G+3`GJ38G%18G`23'53`.$)+````!$,>A-B=U(C;0&H>O9;DR)V$G!
M[1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T1#'A38GL
M2`.4)+@```!-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"2,'A
M'D6)Q$P)V4F)\XGV23'+2`.T),````!$,=A-B>-(C90"H>O9;DR)X$G!ZQM(
MP>`%3`G8B<!(`<),B>A)P>T"2,'@'D&)TTP)Z$F)S8G)23'%2`.,),@```!%
M,>A-B=U.C80&H>O9;DR)WDG![1M(P>8%3`GNB?9,`<9-B>!)P>P"2<'@'D&)
M]4T)X$F)Q(G`33'$1#'B38GL2(V,$:'KV6Y,B>I(P>(%2<'L&T@#A"30````
M3`GBB=)(`=%,B=I)P>L"2,'B'D&)S$P)VDV)PT6)P$DQTTP#A"38````1#'>
M38GC2(VT,*'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'P3(GN2<'M`DC!YAY!B<-,
M">Y)B=6)TDDQ]4@#E"3@````1#'I38G=38V$"*'KV6Y,B=E)P>T;2,'A!4P)
MZ8G)20'(3(GA2<'L`DC!X1Y%B<5,">%)B?2)]DDQS$0QX$V)[$B-E`*AZ]EN
M3(GH2<'L&TC!X`5,">")P$@!PDR)V$@#M"3H````2<'K`DC!X!Y!B=1,"=A)
MB<N)R4DQPT@#C"3P````13'838GC3HV$!J'KV6Y,B>9)P>L;2,'F!4P)WHGV
M3`'&38GH2<'M`DG!X!Y!B?--">A)B<6)P$TQQ4@#A"3X````1#'J38G=2(V,
M$:'KV6Y,B=I)P>T;2,'B!4P)ZHG22`'13(GB2<'L`DC!XAY!B<U,">)-B<1%
MB<!),=1$,>9-B>Q(C;0PH>O9;DR)Z$G![!M(P>`%3`G@B<!(`?!,B=Y(P>8>
M2<'K`DP#A"0``0``3`G>28G308G$23'SB=)(`Y0D"`$``$0QV4V)XTV-A`BA
MZ]EN3(GA2<'K&TC!X05,"=F)R4D!R$R)Z4G![0)(P>$>18G#3`GI28GUB?9)
M,<U(`[0D$`$``$0QZ$V)W4B-E`*AZ]EN3(G82<'M&TC!X`5,">B)P$@!PDR)
MX$G![`)(P>`>08G53`G@28G,B<E),<1%,>!-B>Q.C80&H>O9;DR)[DG![!M(
MP>8%3`GFB?9,`<9-B=A)P>L"2<'@'D&)]$T)V$@#C"08`0``28G#33'#B<!(
M`X0D(`$``$0QVDV)XTG!ZQM(C8P1H>O9;DR)XDC!X@5,"=J)TD@!T4R)ZDG!
M[0)(P>(>08G+3`GJ38G%18G`23'53`.$)"@!``!$,>Y-B=U(C;0PH>O9;DR)
MV$G![1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T2`.4
M)#`!``!$,>%-B>Q-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"
M2,'A'D6)Q$P)V4F)\XGV23'+1#'838GC2`.T)#@!``!(C90"H>O9;DR)X$G!
MZQM(P>`%3`G81(T<$$R)Z$G![0)(P>`>3`GH28G-B<E),<6)PD4QZ$V)W4Z-
MA`:AZ]EN3(G>2<'M&TC!Y@5,">Y,BZPD0`$``$:--`9-B>!)P>P"2<'@'DT)
MX$P)P$2)QDF)Q$B)T$@A\$TAW$D)Q+C<O!N/20'%3`'I38GU20',3(GQ2<'M
M&TC!X05,">E)B?5!`<Q,B=E)P>L"2,'A'DP)V4&)RTD)R$TA\$TAW4T)Z$R+
MK"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&C2P"3(GR2<'N`DC!
MXAY,"?)-B=Y!B=!("=%-(<9,(>%,"?%,B[0D4`$``$D!QDP!]DV)[D@!\4R)
M[DG![AM(P>8%3`GV1(TT#DR)YDG![`)(P>8>3`GF38G$B?%("?))(<Q,(>I,
M">),BZ0D6`$``$D!Q$T!XTV)]$P!VDV)\TG!XP5)P>P;30GC18TD$TV)ZTG!
M[0))P>,>30GK28G-1(G:3`G>22'53"'V3`GN3(NL)&`!``!)`<5-`>A-B>5,
M`<9-B>!)P>T;2<'@!4T)Z$6-+#!-B?!)P>X"2<'@'DT)\$F)UD2)QDT)PTDA
M]DTAXTT)\TR+M"1H`0``20'&3`'Q38GN20'+3(GI2<'N&TC!X05,"?%&C309
M3(GA2<'L`DC!X1Y,">%)B?1!B<M)"<A-(>A-(=Q-">!,BZ0D<`$``$D!Q$P!
MXDV)]$D!T$R)\DG![!M(P>(%3`GB1HTD`DR)ZDG![0)(P>(>3`GJ38G=08G0
M2`G132'%3"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(`?%,B>9)P>T;2,'F!4P)
M[D2-+`Y,B?9)P>X"2,'F'DP)]DV)QHGQ2`GR22'.3"'B3`GR3(NT)(`!``!)
M`<9-`?--B>Y,`=I-B>M)P>,%2<'N&TT)\T6--!--B>-)P>P"2<'C'DT)XTF)
MS$2)VDP)WDDAU$PA[DP)YDR+I"2(`0``20'$30'@38GT3`'&38GP2<'L&TG!
MX`5-">!%C20P38GH2<'M`DG!X!Y-">A)B=5$B<9-"<-)(?5-(?--">M,BZPD
MD`$``$D!Q4P!Z4V)Y4D!RTR)X4G![1M(P>$%3`GI1HTL&4R)\4G![@)(P>$>
M3`GQ28GV20G(08G+32'>32'@30GP3(NT))@!``!)`<9,`?)-B>Y)`=!,B>I)
MP>X;2,'B!4P)\D:--`),B>))P>P"2,'B'DP)XDV)W$&)T$@)T4TAQ$PAZ4P)
MX4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!Y@5,">9$C20.3(GN2<'M
M`DC!YAY,">Y-B<6)\4@)\DDAS4PA\DP)ZDR+K"2H`0``20'%30'K38GE3`':
M38GC2<'M&TG!XP5-">M%C2P338GS2<'N`DG!XQY-"?-)B<Y$B=I,"=Y)(=9,
M(>9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G![AM)P>`%30GP18TT,$V)
MX$G![`))P>`>30G@28G41(G&30G#22'T32'K30GC3(ND)+@!``!)`<1,`>%-
MB?1)`<M,B?%)P>P;2,'A!4P)X4:-)!E,B>E)P>T"2,'A'DP)Z4F)]4&)RTD)
MR$TA\$TAW4T)Z$R+K"3``0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&
MC2P"3(GR2<'N`DC!XAY-B=A,"?)!B=9("=%-(?!,(>%,"<%,BX0DR`$``$D!
MP$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$#DR)YDG![`)(P>8>3(GQ3`GF
M08GT2`GR3"'A3"'J2`G*2(N,)-`!``!(`<%)`<M,B<%(`X0DV`$``$P!VDV)
MPTC!X05)P>L;3`G9B<E,`?!(`<I,B>E)P>T"2,'A'D&)TTP)Z4V)Y4&)ST@)
MSDTA_4PAQDP)[DV)W4@!\$R)WDG![1M(P>8%3`GNB?9(`?!,B<9)P>@"2,'F
M'D&)Q4D)\+[6P6+*3#'!,<I(BXPDX`$``$@!\4D!S$R)Z4P!XDV)[$C!X05)
MP>P;3`GAB<E(`<I,B=E(P>$>2<'K`D&)U$D)RTR)P4V)YDPQV4G![AM%B<`Q
MR$B+C"3H`0``2`'Q20'/2HT,.$R)X$C!X`5,"?")P$R--`%,B>A)P>T"2,'@
M'DR)V46)VTD)Q4B+A"3P`0``18GW3#'I,<I,B?E(`?!(P>D;3`'`2`'"3(GX
M2,'@!4@)R$B+C"3X`0``B<!(`<),B>!)P>P"2,'@'D@!\4&)T$P)X$P!V4V)
MZTDQPTV)Q$6)[44QWDG![!M.C1PQ3(G!2,'A!4P)X8G)20'+3(GY2<'O`DC!
MX1Y%B=Q)"<](BXPD``(``$@!\4P!Z4F)Q8G`33']1#'J3(TL$4R)XDR)X4C!
MZ1M(P>(%2`G*3(G!2<'H`HG22,'A'DD!U4B+E"0(`@``3`G!38GX18GN18G_
M23'(2`'R13'#2`'03(GR3HT$&$R)\$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)
MX$G![`)(P>`>18G#20G$2(N$)!`"``!,,>)!,=5,B=I(`?!,`?A)`<5,B=A(
MP>`%2,'J&T@)T$R)\DG![@*)P$C!XAY)`<5(BX0D&`(``$P)\D6)[T@!\$@!
MR$R)X46)Y$@QT4$QR$R)^4D!P$R)^$C!Z1M(P>`%2`G(B<!)`<!,B=A)P>L"
M2,'@'D6)QDD)PTB+A"0@`@``3(GQ2,'I&T@!\$P!X$F)U(G233'<13'E3HTD
M*$R)\$C!X`5("<A(BXPD*`(``(G`20'$3(GX2<'O`D@!\4C!X!Y%B>5,"?A(
M`<I,B=E(,<%%B=M!,<A,B>E)`=!,B>I(P>D;2,'B!4@)RHG220'03(GR2<'N
M`DC!XAY%B<=)"=9(BY0D,`(``$R)^4C!Z1M(`?),`=I)B<.)P$TQ\T4QW$Z-
M'"),B?I(P>(%2`G*3(GI2<'M`HG22,'A'DD!TTB+E"0X`@``3`GI18G<2`'R
M2`'03(GR18GV2#'*03'03(GB20'`3(G@2,'J&TC!X`5("=!(B<J)R8G`20'`
M3(GX2<'O`DC!X!Y%B<5)"<=(BX0D0`(``$@!\$PQ^DP!\$$QTTR)ZDD!PTR)
MZ$C!ZAM(P>`%2`G03(GB2<'L`HG`2,'B'DD!PTB+A"1(`@``3`GB18G>28G4
M2`'P2`'(3(GY18G_2#'1B=)!,<A*C0P`3(GP38GP2<'H&TC!X`5,"<")P$@!
MP4R)Z$G![0)(P>`>08G(20G%2(N$)%`"``!-,>Q%,>--B<1(`?!)P>P;3`'X
M20'#3(G`2,'@!4P)X(G`20'#3(GP2,'@'DG![@)%B=Q,"?!,B[0D6`(``$D!
M]DD!UDR)ZD6)[4@QPC'128T4#DR)X4V)YDG![AM(P>$%3`GQB<E(`<I,B<%)
MP>@"2,'A'D&)UDD)R$B+C"1@`@``2`'Q3`'I28G%B<!-,<5%,>M-B?5)`<M,
MB?%)P>T;2,'A!4P)Z8G)20'+3(GA2<'L`DC!X1Y%B=U)"<Q(BXPD:`(``$@!
M\4@!R$R)P46)P$PQX3'*2(T,$$R)Z$R)ZDC!ZAM(P>`%2`G03(GR2<'N`DC!
MXAZ)P$D)UDB+E"1P`@``2`'!B<A(`?),`<)-B>!-,?!%,<-)B<!,`=I)B<-)
MP>`%2<'K&TT)V$F)PTC!Z`))P>,>00'03(GJ20G#2(N$)'@"``!(P>(>2<'M
M`D$!VTD)U42)XDR)7Q!(`?!$`>U(`<),B?!(B6\83#'H,<%(C00*3(G"3(G!
M2,'B!4C!Z1M%`<A("<I,B4<(`=!!`<)$`W<@2(N$)(@"``!D2#,$)2@```!,
MB1=,B7<@=1)(@<28`@``6UU!7$%=05Y!7\/HXN/__V:005=!5D%505154TB#
M[`A(A?\/A+$```!,BSVJ>"``387_#X2A````#[8'A,!T!#P]=5Y%,>1)BQ](
MA=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_HPN+__X7`=0="@#PC
M/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD
M!&:0,<!(B=Y(B>_H`____TB%P'0V2&-4)`1(BP6Z=R``2(T$T$B+4`A(A=)(
MB1!TTF:02(/`"$B+4`A(A=)(B1!U\.N^9@\?1```2(M$)`AD2#,$)2@```!U
M!TB#Q!A;7</HC.+__V:09BX/'X0``````$%7059!54%455-(B?-(B?U(@^PH
M9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z#GB__](C70D%$F)Q$B)
M[S'`Z%?^__](A<`/A`X!``!(B<=)B<7H$^+__TPYX`^#X@```$QC="042<'F
M`P^V10"$P`^$K0$``#P]#X2E`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V
M$(32=?!(*>A(F$P#-;QV(`!*C7P@`NCZXO__2(7`28D&#X1[`0``2&-4)!1(
MBP6:=B``2(U-`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(
M@\$!#[9!_TB#P@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`
M2(MT)!AD2#,T)2@````/A1$!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#
M_TF#Q0&$P$&(1?]U[.O"9I!,BST!=B``28,_``^$OP```$R)^#'2ZPL/'X0`
M`````$2)ZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%_X4@`(7`=5M(B??'
M!>Z%(``!````Z/GA__](A<`/A'T```!-8\5,B?Y(B<=.C33%`````$R)1"0(
M3(GRZ(+B__],BT0D"$B)P4B)!7MU(`!*QT3!"`````!$B6PD%.EO_O__3(G_
MZ#CB__](A<!(B<%(B053=2``="9-8\5.C33%`````.O)#Q]``#'`Z7;^__^0
MOA````!%,>WI7O___[C_____Z=O^___H-.#__P\?0`!!5T%6055!5%532('L
MN````&1(BP0E*````$B)A"2H````,<!(A?]T"(`_`$F)_G4O2(N$)*@```!D
M2#,$)2@````/A20!``!(@<2X````6UU!7$%=05Y!7\-F#Q]$``#H:]___TB%
MP$B)PW3$2(U$)!!(C2V,&P``3(TEA!L``$R-/8`;``!(B00D2(G?Z(WA__](
MA<`/A+0```!,C4@3N0(```!(B>],B<[SIG3<N0,```!,B<Y,B>?SIG3-3(GW
M3(E,)`CH5=___TR+3"0(28G%3(G/Z$7?__]!C7P%`DAC_^AXX/__3(M,)`A)
MB<5(B<=-B?!,B?E(Q\+_____O@$````QP.C4X?__2(L4)+\!````3(GNZ*/>
M__^#^/],B>]T$(M$)"@E`/```#T`0```=##H)M[__TR)[^C^W?__Z43___]F
M#Q^$``````!(B=_H6-___TR)]^BPWO__Z<S^___HEO[__^O.Z+_>__\/'T0`
M`&8N#Q^$``````!32(G^2(G[OP$```!(@>R@````2(GB9$B+!"4H````2(F$
M))@````QP.C2X/__A<!U/HM4)!B!X@#P``"!^@!```!T-('Z`*```'0L2(N,
M))@```!D2#,,)2@```!U,$B!Q*````!;PP\?A```````,<#KV`\?0`"^`@``
M`$B)W^@[X/__A<`/E,`/ML#KO>@<WO__9I!F+@\?A```````059!54F)]D%4
M54F)_%-(C3W8&0``NO\/``!(@>P0$```2(GC2(G>9$B+!"4H````2(F$)`@0
M```QP.@QW?__A<`/CHD```"-4/]$BRU_<B``2&/J@#PL`'162&/H2(GJOB\`
M``!(B=_H4][__TB%P'1&1(GOZ+;>__](B>E(B=I,B>9(B<?HM=___TB+A"0(
M$```9$@S!"4H````=3M(@<00$```6UU!7$%=05[#9I"%TG6I#Q]``$2)[^AP
MWO__3(GR3(GF2(G'Z(+=___KNT2++?EQ(`#KW^@RW?__9I!(@^P(BSWF<2``
MZ$'>__](BQ5Z<2``2(T-ZQH``$B--?@8``!(B<=(@\0(Z6#>__](@^P(BSVV
M<2``Z!'>__](B<?HN?___XL]HW$@`.C^W?__3(T%6!H``$B-%;`3``!(C371
M&```13')2(G'2(/$"$R)P>EGWO__#Q^``````%532('L*"```&1(BP0E*```
M`$B)A"08(```,<!(B>-(C:PD$!```.@$W/__3(T-91@``$B-#9,8``!!B<"Z
M`1```+X!````2(G?,<#H#]___[H`$```2(GN2(G?Z*_;__^%P'A3C7@!2(G#
M2&/_Z&W=__](A<!(B<%T&$ACVTB)[DB)QTB)VN@DW?__2(G!Q@08`$B+E"08
M(```9$@S%"4H````2(G(=1-(@<0H(```6UW##Q]$```QR>O7Z._;__\/'T0`
M`&8N#Q^$``````#I*____Y!F+@\?A```````05=!5D%5051)B?154TB)^TB-
M/>(7``!(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z+7W__^^+P``
M`$B)WTB)Q>BEV___2(7`=$!(C3VK%P``2(G>,<#H[_C__TB)V$B+C"2H$```
M9$@S#"4H````#X5Z`0``2('$N!```%M=05Q!74%>05_##Q\`2(G?Z"C;__](
MC35P%P``3(GG08G%Z$;=__](A<!)B<=TGD&#Q0%!@#\`3(VD)*````!,C70D
M$`^$R0````\?`$B%[7033(G^2(GOZ,#;__^%P`^$B@```$R)_^C0VO__B<)(
MF$&`?`?_+W47#Q]``(/J`4ACPD&`?`?_+T'&!`<`=.U$`>J!^O\/```/CR[_
M__](@^P(2(T-VA<``$R-#=T6``!338GXN@`0``"^`0```$R)YS'`Z#3=__],
MB?),B>:_`0```.@$VO__A<!:6740BT0D*"4`\```/0"```!T5DB--986```Q
M_^APW/__2(7`28G'#X3$_O__08`_``^%.O___TB%[7052(T]`Q8``+D"````
M2(GN\Z9TQ&:03(T][A4``+H!````Z5+___\/'X``````O@$```!,B>?H"]S_
M_X7`=9E(C3TB%@``3(GFZ&CW__],B>?H<-S__^EO_O__Z-;9__]F#Q]$```/
MMA=(B?B$TG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7N\\,/'T``\\-F#Q]$
M``!(A?\/A,\```!54TB#[`@/MB]`A.UT*4B)^^AQV?__2(U4`_](.=-R$.L[
M#Q]$``!(@^H!2#G3=#>`.B]T\NL=2(/$"$B-/2H5``!;7>G>V___9@\?1```
M@#HO=#A(@^H!2#G3<O)(.=-U*@\?1```0(#]+W3*2(/$"$B-/6`5``!;7>FH
MV___#Q^$``````"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`0``!W.TB-/0QN
M(`!(@\(!N0`0``!(B=[H:]K__TB-!?1M(`!(@\0(6UW##Q]$``!(C3V6%```
MZ4S;__\/'T``,<#KX`\?0`!32(T]ZQ0``$B#[$!D2(L$)2@```!(B40D.#'`
M#[<%718``$B-7"0,\P]O!3`6```/*40D$&:)1"0P,<#S#V\%+!8```\I1"0@
MZ%+U__](C3VG%```,<#H1/7__TB-/:$4```QP.@V]?__2(T]G!0``#'`Z"CU
M__](C3V5%```,<#H&O7__TB-/9<4```QP.@,]?__2(T]/A0``#'`Z/[T__](
MC3V'%```,<#H\/3__TB-/8,4```QP.CB]/__2(T]?Q0``#'`Z-3T__](C3T/
M%```,<#HQO3__TB-/6T4```QP$B)WNCE\___2(7`=!%(C3U#%```2(G&,<#H
M+_7__TB-/5<4```QP$B)WNB^\___2(7`=!%(C3U3%```2(G&,<#H"/7__TB-
M/4T4```QP$B)WNB7\___2(7`=$)(C3V4$P``2(G&,<#HX?3__TB--5(4``!(
MC3VW$P``,<#HS/3__TB+1"0X9$@S!"4H````=6)(@\1`6\-F#Q]$``!(C3T%
M%```,<!(B=[H/_/__TB%P'4J2(UT)"%(C3W[$P``N0H```#SIG6D2(UT)"M(
MC3UY$P``,<#H<O3__^N/2(T]:1,``$B)QC'`Z%_T___I>?___^C5UO__#Q]$
M``!(@^P89$B+!"4H````2(E$)`@QP(L%9FL@`(/X_W092(M\)`AD2#,\)2@`
M``!U0$B#Q!C##Q]``$B-="0$2(T]#!,``#'`Z*7R__](B<(QP$B%TG02#[82
M@/HP#Y7!,<"$T@^5P"'(B043:R``Z[#H7-;__V:09BX/'X0``````$B#[`CH
M5];__XG'Z`#6__](A<!T"TB+`$B#Q`C##Q\`,<#K]&:09BX/'X0``````$%4
M54B)_5-(C3T,$P``2(/L$&1(BP0E*````$B)1"0(,<!(C70D!.@4\O__2(7`
M2(GN='R`.`!(B<-T=$B)Q^A\V/__2(7`=75(B>_HO]7__TB)WTF)Q.BTU?__
M28U\!`+HZM;__TB#[`A,C0WN$0``2(T-WQ(``%-(Q\+_____2(G'28G$28GH
MO@$````QP.@[V/__2(T]?A(``$R)YC'`Z/KR__]86NL49@\?1```2(T]8Q(`
M`#'`Z.+R__](BT0D"&1(,P0E*````'4)2(/$$%M=05S#Z$35__\/'T``05=!
M5DF)_D%5051(C3U7$0``55-(@>R8@0``9$B+!"4H````2(F$)(B!```QP$B-
M!2$2``!,C60D+$C'1"1``````$C'A"28`````````$C'1"1@`````$B)1"0P
M2(T%L1```$R)YDB)1"0X2(T%CA$``$B)1"1P2(T%>Q$``$B)1"1X2(T%T!$`
M`$B)A"2`````2(T%?1$``$B)A"2(````2(T%NA$``$B)A"20````2(T%DA$`
M`$B)1"102(T%HQ$``$B)1"18,<#HD/#__TB%P'0)@#@`#X5B`@``,<#H"_[_
M_TB%P$B)PP^$GP(``$B)W^@WU/__2(U\``'H;=7__X`[`$F)Q70W3(T]7A$`
M`$R)[0\?`$0/M@-(B>\QP$R)^4C'PO____^^`0```$B#PP%(@\4"Z+/6__^`
M.P!UUDB-7"1P2(T]LQ```.L02(/#"$B+.TB%_P^$@`$``#'`3(GFZ/;O__](
MA<!(B<5TWH`X`'392(G'Z!'U__^%P'3-2(GOZ$76__](A<!)B<</A$D!``!F
M#Q^$``````!,B?J+"DB#P@2-@?_^_O[WT2'()8"`@(!TZ8G!P>D0J8"````/
M1,%(C4H"2`]$T8G!`,%,B>E(@]H#3"GZBS%(@\$$C8;__O[^]]8A\"6`@("`
M=.F)QL'N$*F`@```#T3&2(UQ`D@/1,Z)QD``QDB#V0-,*>F-G`H$!```2&/;
M2(G?Z$G4__](B<5(C05-$```055,C0U'#P``2(T--!```$V)^%!(Q\+_____
MO@$```!(B>\QP.B5U?__OL`!``!(B>_H*-+__X/X_T%805EU$NCJT?__1(L(
M08/Y$0^%DP@``$R-K"2@````2(GNOP$```!,B>KH]=3__X7`08G'=1>+A"2X
M````)0#P```]`$````^$1P$``$F+#DB+/7UG(`!(C16>$```28GHO@$````Q
MP#';Z.74___I@````#'M9@\?1```2&/%2(M<Q#!(A=MT.X`[`'0V2(G?@\4!
MZ(OS__^%P'3?2(G?Z+_4__](A<!)B<</A8/^__](8\5(BUS$,$B%VW7+9@\?
M1```13'_Z6C^__\/'X0``````$B)QTB)!"3HU/O__TB+!"1(B<?H>-3__TB)
MPP\?1```2(N,)(B!``!D2#,,)2@```!(B=@/A94(``!(@<28@0``6UU!7$%=
M05Y!7\,/'T``2(T]LPX``#'M2(7_="9FD#'`3(GF@\4!Z+/M__](A<!T!8`X
M`'4I2&/%2(M\Q%!(A?]UW+\-````2(T=?PX``.B;TO__28G%Z2[]__\/'P!(
MB<?HZ-/__TB%P$B)PP^%_?S__^O!9BX/'X0``````(N$)+P```")!"3H0='_
M_SD$)`^%H?[__XN$)+@````E_P$``#W``0``#X6*_O__2(G?Z#G2__](C3T'
M#@``2(G#3(GF,<#H%>W__TB%P`^$7`$``$B)Q^ATT___28L^2(G&Z`GU__](
MA<!)B<0/A#T!``!,B>?HM=#__X/X`WXX2&/02(T]^0T``+D%````28UT%/SS
MIG4@@_@$#X3O!0``@^@$2)A!@'P$_R\/A-X%``!F#Q]$```QP.BQ^?__A<!U
M%3'V3(GGZ$/2__^%P$&)Q@^%Z````$B--5D-``!(C3W:#```3(TEU`T``#'`
M3(TMBPP``.C%[?__Z,#/__]!5$R-#7@,``!02(T-BPT``$C'PO____])B>B^
M`0```$B)WS'`Z,;2__]86NM%9I#H*\___X,X$75+Z('/__]!@\<!2(/L"$B-
M#5P-``!!5$%738GI4$F)Z$C'PO____^^`0```$B)WS'`Z('2__](@\0@OL`!
M``!(B=_H$,___X/X_W2K2(GOZ,/.__](C3W5"P``2(G>,<#H(NW__TB)W^AZ
M^?__Z;7]__\/'T0``$V+)NF[_O__#Q^$``````"Z`@```$C'QN[___^)Q^C=
MT?__2(V$)(`!``"Z!@```$2)]TB)QDB)!"3H$=#__X"\)(`!````=0Z`O"2!
M`0``0P^$>`4``#'2,?9$B??HG='__[B)J\WO2,>$)*`````!(T5G2,>$)+@`
M``!V5#(02(F$)*@```!(+8O.$E=(QX0DR`````````!(B80DL````$@%\@08
M*TC'A"30`````````$B)A"3`````28U%.,>$)!@!````````2(E$)`A(BS0D
MN@"```!$B??H;\___X7`28G$08G`#XYQ`0``2(N\),@```!)8\1(BY0DT```
M`(TTQT@Y_DB)M"3(````2(/2`$C!Z!U(`=!(B80DT````$ACA"08`0``A<`/
MA!T!``!(BTPD"$&X0````$B+-"1!*<!%.<1%#T[$2(T\`4ECT$F)UTB)5"00
MZ##/__^+A"08`0``1`'X@_A`B80D&`$```^%5O___T6)X$R)[T4I^$R+?"00
M3`,\)$2)1"0<Z`K4__]$BT0D'`\?1```08/X/WYY08U`P(E$)!S!Z`9!B<2)
M1"0028/$`4G!Y`9-`?P/'T0``/-!#V\'3(GO28/'0`\1A"38````\T$/;T?0
M#Q&$).@```#S00]O1^`/$80D^````/-!#V]'\`\1A"0(`0``Z)73__]-.?QU
MN(M$)!!$BT0D','@!D$IP$B+?"0(26/0N4@```!,B?Y$B40D$.A'SO__1(M$
M)!!$B80D&`$``.F%_O__#Q]$``!,BSPDZ4?___\/'X``````1(GWZ)C-__],
MBZ0DR````$R+M"30````3(G@2,'H`X/@/XU0`4B8QH0$V````("#^C@/CX,"
M``"X.````#'V*=!(8]*#^`A)C505.`^#VP(``*@$#X6&`P``A<!T"Z@"Q@(`
M#X6*`P``3(GP3(GO1(BT)!,!``!(P>@81(BD)!<!``!,C:PD4`$``(B$)!`!
M``!,B?!(P>@0B(0D$0$``$R)\$R--;8)``!(P>@(B(0D$@$``$R)X$C!Z!B(
MA"04`0``3(G@2,'H$(B$)!4!``!,B>!%,>1(P>@(B(0D%@$``.A9TO__2(N$
M)*````!(B<*(A"0S`0``2,'J&$0/ML*(E"0P`0``2(G"2,'J$(B4)#$!``!(
MB<)(BX0DJ````$C!Z@B(E"0R`0``2(G"B(0D-P$``$C!ZAB(E"0T`0``2(G"
M2,'J$(B4)#4!``!(B<)(BX0DL````$C!Z@B(E"0V`0``2(G"B(0D.P$``$C!
MZAB(E"0X`0``2(G"2,'J$(B4)#D!``!(B<)(BX0DN````$C!Z@B(E"0Z`0``
M2(G"B(0D/P$``$C!ZAB(E"0\`0``2(G"2,'J$(B4)#T!``!(B<)(BX0DP```
M`$C!Z@B(E"0^`0``2(G"B(0D0P$``$C!ZAB(E"1``0``2(G"2,'J$(B4)$$!
M``!(B<)(P>H(B)0D0@$``.D,````#Q\`1@^VA"0P`0``2XU\90`QP$R)\4C'
MPO____^^`0```$F#Q`'HJ,W__TF#_!1UTDB-!6P(``#&A"1X`0```%!!54B-
M#28(``!,C0T3!P``O@$```!)B>A(Q\+_____2(G?,<#H:<W__UE>Z??Z__]F
MD$V+=@A-A?8/A!OZ__],B??HB\K__TB#^`,/A@GZ__])C70&_$B-/<T'``"Y
M!0```/.F30]$YNGM^?__N$````!(8\HIT$F-3`TX=`\QTHG6@\(!.<+&!#$`
M<O-,B>_H7=#__V8/[\`/$80DV````$G'16@`````00\114A!#Q%%6.EC_?__
M28L.2(L](%\@`$B-%0$(``!)B>B^`0```#'`,=OHB,S__^DC^/__B<%(QP(`
M````2,=$"O@`````2(U*"$B#X?A(*<H!T(/@^(/X"`^"$?W__X/@^#'2B=>#
MP@@YPDB)-#ER\^GZ_/__@+PD@@$``$$/A7KZ__^`O"2#`0``0P^%;/K__X"\
M)(0!``!(#X5>^O__@+PDA0$``$4/A5#Z__^Z`@```$C'QL;___]$B??HY<O_
M_TR+/"2Z*0```$2)]TR)_N@ARO__2(T%VP8``%!!5^ER_O__9I#'`@````#'
M1`+\`````.EV_/__,?]FB7P"_NEJ_/__Z"S)__]FD&8N#Q^$``````!!5T%6
M055!5%532(/L&(L]S%T@`&1(BP0E*````$B)1"0(,<!,C6PD!.@2RO__BSVL
M72``2(G#Z`3*__\/MI.X````2(T].@4``$R)[HB0N0```#'`Z.;D__](A<!T
M"8`X,0^$"`,``#'`Z`'P__^+/6M=(`#HQLG__TB--1H&``"Y"P```+H!````
M2(G'Z&W)__](A<`/A,0```"#/:UM(``!2(M`$$2+-3)=(`!,BV`H#XZO````
M,>V[`0```.LZ#Q^``````$F+=Q!(BP5U;2``2&/32(L\T.@1R?__A<"+%6EM
M(``/A0@"``"#PP&#Q0$YTP^-^@$``$2)]^@]R?__,<E(8]5,B>9(B<?H#<K_
M_TB%P`^$S`$``$R+.$2+-;I<(`!!BT<,)0`$(``]``0``'221(GWZ`+)__],
MB?ZY`@```#'22(G'Z"#(__]$BS6)7"``2(G&Z6W___^01(LU>5P@`$2)]^C1
MR/__2(TU*@4``+D#````N@$```!(B<?H>,C__TB%P$B)PW0U2(M`$(L]1EP@
M`$B+*.B>R/__2(T5^00``$B)QTB)[NBLQ___2(M#$$B+&/9##D`/A>L!``"+
M/15<(`#H<,C__TB--=`$``"Y`P```+H!````2(G'Z!?(__](A<!(B<-T/4B-
M/5H#```QP$R)[N@^X___2(7`2(G%#X1R`0``2(M#$(L]R%L@`$B+&.@@R/__
M2(GJ2(G'2(G>Z#+'__^+/:Q;(`#H!\C__TB--6D$``"Z`0```$B)Q^@3R/__
MBSV-6R``2(G#Z.7'__](C15<!```2(G>2(G'Z//&__^+/6U;(`#HR,?__TB-
M/<H"``#&@+D`````3(GN,<#HL.+__TB%P$B)PTB)!;MK(``/A)T```"^P`$`
M`$B)W^C`Q?__C5`!@_H!=@F#^!$/A0\!``!(BT0D"&1(,P0E*`````^%]@``
M`$B#Q!A;74%<05U!7D%?PP\?0`"+%6)K(`!$BS7K6B``C4+_.>@/A6?^__^#
M^@$/CE[^__^[`0```&:01(GW@\,!Z"7'__],B>9(B<?H:L7__SD=)&L@`$2+
M-:U:(`!_V^DM_O__9@\?1```2(L]`6L@`.B4\/__2(7`2(G#2(D%_VH@``^%
M1/___TB-/3H$```QP.@#Q___#Q\`@'@!``^$]?S__^GI_/__D$B+!<%J(`"+
M/5-:(`!(BRA(BT,02(L8Z*3&__](B>Y(B=_H:>?__^F"_O__#Q]``(L]*EH@
M`.B%QO__2(G>2(G'Z-K&___I^OW__^A0Q?__B<%(BP5O:B``2(T]Z`,``$B)
MVDB+,#'`Z(/&__\/'P!54TB)_4B#[`CH@NO__P^V$$B)PX32=!H/'X0`````
M`$B#P`&`^B\/MA!(#T38A-)U[C'`Z"?N__](A>UT'87`=!F`?0``=!-(C3T?
M`@``N00```!(B=[SIG0'2(/$"%M=PTB#Q`A(B>];7>F0Y/__2(L-85D@`.E$
MQ?__#Q]``$%7059)B==!54%43(TESE0@`%5(C2W.5"``4T&)_4F)]DPIY4B#
M[`A(P?T#Z%_#__](A>UT(#';#Q^$``````!,B?I,B?9$B>]!_Q3<2(/#`4@Y
MW77J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L"$B#Q`C#````
M`0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E<P!0
M05)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$52
M3#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!5
M4T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E
M<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-#4`+64`+2T`````````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("```````````'!E<FQX<VDN8P`````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S
M970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]
M("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=
M.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q
M6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A
M9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN
M(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@
M)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N
M;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(
M+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E
M7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F
M+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC
M<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L
M("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2([
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H
M*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`]
M(%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@
M;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/
M3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@
M/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U
M9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG
M="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F
M:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I
M9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*
M?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'
M0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH```````$;`SOL````'````-B#__\X`0``F(?__V`!``"H
MA___2`8``-B)__\(`0``Z(K__W@!``#XH/__R`$``,BA__\4`@``6*+__T`"
M``"HI/__C`(``"BF___8`@``R*;___P"``"HI___0`,``-BG__]8`P``**C_
M_W`#``#XJ/__G`,```BI__^P`P``"*O__Q`$```XJ___)`0``"BL__]T!```
M"*[__Y@$``"(KO__M`0``+BN___0!```F*___Q`%``"XN___R`4``*B___\4
M!@``&,#__W@&```HP/__D`8``)C`___8!@```````!0``````````7I2``%X
M$`$;#`<(D`$'$!0````<````R(C__RL``````````````!0``````````7I2
M``%X$`$;#`<(D`$``"0````<````F(+__\`#````#A!&#AA*#PMW"(``/QH[
M*C,D(@`````4````1````#"&__\(``````````````!,````7````&B)__\.
M%@```$(.$(\"0@X8C@-&#B"-!$(.*(P%1`XPA@9!#CB#!T<.T`4#YA4*#CA!
M#C!!#BA"#B!"#AA"#A!"#@A!"P```$@```"L````*)___\P`````0@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A)"P`H````^````*R?__^$`````$$.$(8"00X8@P-'#C`"<PH.&$$.
M$$$."$$+`$@````D`0``$*#__TP"````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'2@Y@`R8!"@XX00XP00XH0@X@0@X80@X00@X(1`M(````<`$`
M`!2B__]Q`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.\`%^
M"@XX00XP00XH0@X@0@X80@X00@X(1PL`(````+P!``!(H___E`````!!#A"#
M`E(.L`$"4PH.$$$."$D+0````.`!``#$H___W@````!"#A".`D(.&(T#10X@
MC`1!#BB&!40.,(,&4P[`(`*$"@XP00XH00X@0@X80@X00@X(0PL4````)`(`
M`&"D__\P`````$0.$&<."``4````/`(``'BD__])`````$0.$'T."``H````
M5`(``+"D___!`````$$.$(8"00X8@P-'#L!``J<*#AA!#A!!#@A&"Q````"`
M`@``5*7__P4`````````7````)0"``!0I?__^@$```!"#A"/`D(.&(X#0@X@
MC01"#BB,!40.,(8&00XX@P=1#O`A`F0*#CA!#C!!#BA"#B!"#AA"#A!"#@A$
M"P*6#O@A3PZ`(FH.^"%!#O`A````$````/0"``#PIO__*@````````!,````
M"`,```RG___L`````$H.$(8"00X8@P-$#B!U"@X82,,.$$'&#@A+"V(*#AA(
MPPX00<8."$T+`D`.&$$.$$$."$;#QE`.((,#A@(``"````!8`P``K*?__]L!
M````00X0@P)+#E`#;`$*#A!!#@A'"Q@```!\`P``:*G__W0`````1`X@;PH.
M"$4+```8````F`,``,RI__\D`````$0.$%@*#@A$"P``/````+0#``#@J?__
MW`````!"#A",`D$.&(8#1`X@@P1+#C`"6`XX3PY`;@XX00XP:@H.($$.&$$.
M$$(."$$+`+0```#T`P``@*K__Q0,````0@X0CP)"#AB.`T4.((T$0@XHC`5(
M#C"&!D$..(,'1P[0@P(#&`(.V(,"4@[@@P)H#MB#`D(.T(,"`Q(!"@XX00XP
M00XH0@X@0@X80@X00@X(10L#<@$.V(,"2`[@@P)A#MB#`D$.T(,"6P[8@P))
M#N"#`D(.Z(,"1`[P@P)=#M"#`@/K!`[8@P)"#N"#`F@.V(,"00[0@P(#7@$*
M#MB#`D(.X(,"1PM(````K`0``.BU___M`P```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T0.4`/+`@H..$$.,$$.*$(.($(.&$(.$$(."$4+,```
M`/@$``",N?__<`````!!#A"&`D$.&(,#1PX@`E8*#AA!#A!!#@A!"T0.&$0.
M$$$.""P````L!0``6('__RT"````00X0A@)!#AB#`T0.4`.]`0H.&$$.$$$.
M"$$+`````!0```!<!0``F+G__PP``````````````$0```!T!0``D+G__V4`
M````0@X0CP)"#AB.`T4.((T$0@XHC`5(#C"&!D@..(,'30Y`<@XX00XP00XH
M0@X@0@X80@X00@X(`!````"\!0``N+G__P(`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M8"$````````@(0````````````````````````````````````````$`````
M`````0`````````!`````````,L!`````````0`````````:`@````````P`
M````````0!H````````-`````````"17````````&0````````"0JR``````
M`!L`````````"``````````:`````````)BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````R00````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````N!0````````'`````````"`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````H!(```````#___]O``````(`
M````````\/__;P````#2$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````+BK(```````````````````
M`````````'8:````````AAH```````"6&@```````*8:````````MAH`````
M``#&&@```````-8:````````YAH```````#V&@````````8;````````%AL`
M```````F&P```````#8;````````1AL```````!6&P```````&8;````````
M=AL```````"&&P```````)8;````````IAL```````"V&P```````,8;````
M````UAL```````#F&P```````/8;````````!AP````````6'````````"8<
M````````-AP```````!&'````````%8<````````9AP```````!V'```````
M`(8<````````EAP```````"F'````````+8<````````QAP```````#6'```
M`````.8<````````]AP````````&'0```````!8=````````)AT````````V
M'0```````$8=````````5AT```````!F'0```````'8=````````AAT`````
M``"6'0```````*8=````````MAT```````#&'0```````-8=````````YAT`
M``````#V'0````````8>````````%AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````!06@```````$=#
M0SH@*%5B=6YT=2`W+C,N,"TR,W5B=6YT=3(I(#<N,RXP`$=#0SH@*%5B=6YT
M=2`W+C,N,"TQ-G5B=6YT=3,I(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`#@"````````.`(````````<`````````````````````0``````````````
M`````!,````'`````@````````!4`@```````%0"````````(```````````
M``````````0````````````````````A````!P````(`````````=`(`````
M``!T`@```````"0````````````````````$````````````````````-```
M`/;__V\"`````````)@"````````F`(```````#X``````````4`````````
M"````````````````````#X````+`````@````````"0`P```````)`#````
M````>`D````````&`````0````@`````````&`````````!&`````P````(`
M````````"`T````````(#0```````,D$```````````````````!````````
M````````````3@```/___V\"`````````-(1````````TA$```````#*````
M``````4``````````@`````````"`````````%L```#^__]O`@````````"@
M$@```````*`2````````@``````````&`````@````@`````````````````
M``!J````!`````(`````````(!,````````@$P```````)@!````````!0``
M```````(`````````!@`````````=`````0```!"`````````+@4````````
MN!0```````"(!0````````4````7````"``````````8`````````'X````!
M````!@````````!`&@```````$`:````````%P````````````````````0`
M``````````````````!Y`````0````8`````````8!H```````!@&@``````
M`,`#```````````````````0`````````!``````````A`````$````&````
M`````"`>````````(!X````````(````````````````````"``````````(
M`````````(T````!````!@`````````P'@```````#`>````````\C@`````
M`````````````!````````````````````"3`````0````8`````````)%<`
M```````D5P````````D````````````````````$````````````````````
MF0````$````"`````````#!7````````,%<```````!8/P``````````````
M````"````````````````````*$````!`````@````````"(E@```````(B6
M````````[`````````````````````0```````````````````"O`````0``
M``(`````````>)<```````!XEP`````````&```````````````````(````
M````````````````N0````X````#`````````)"K(```````D*L````````(
M````````````````````"``````````(`````````,4````/`````P``````
M``"8JR```````)BK````````"`````````````````````@`````````"```
M``````#1`````0````,`````````H*L@``````"@JP```````!,`````````
M```````````0````````````````````W@````8````#`````````+BK(```
M````N*L````````0`@````````8`````````"``````````0`````````(@`
M```!`````P````````#(K2```````,BM````````,`(`````````````````
M``@`````````"`````````#G`````0````,``````````+`@````````L```
M`````"`````````````````````(````````````````````[0````@````#
M`````````""P(```````(+````````"($```````````````````(```````
M`````````````/(````!````,````````````````````""P````````2```
M``````````````````$``````````0`````````!`````P``````````````
M``````````!HL````````/L````````````````````!````````````````
#````
